@@ -15,6 +15,7 @@ import (
 	"net"
 	"net/http"
 	"os"
+	"path"
 	"strings"
 	"time"
 
@@ -23,6 +24,27 @@ import (
 	"github.com/schollz/mnemonicode"
 )
 
+// Get or create home directory
+func GetConfigDir() (homedir string, err error) {
+	homedir, err = os.UserHomeDir()
+	if err != nil {
+		return
+	}
+
+	if envHomedir, isSet := os.LookupEnv("CROC_CONFIG_DIR"); isSet {
+		homedir = envHomedir
+	} else if xdgConfigHome, isSet := os.LookupEnv("XDG_CONFIG_HOME"); isSet {
+		homedir = path.Join(xdgConfigHome, "croc")
+	} else {
+		homedir = path.Join(homedir, ".config", "croc")
+	}
+
+	if _, err = os.Stat(homedir); os.IsNotExist(err) {
+		err = os.MkdirAll(homedir, 0700)
+	}
+	return
+}
+
 // Exists reports whether the named file or directory exists.
 func Exists(name string) bool {
 	if _, err := os.Stat(name); err != nil {
@@ -52,11 +74,11 @@ func HashFile(fname string, algorithm string) (hash256 []byte, err error) {
 	if fstats.Mode()&os.ModeSymlink != 0 {
 		var target string
 		target, err = os.Readlink(fname)
+		if err != nil {
+			return nil, err
+		}
 		return []byte(SHA256(target)), nil
 	}
-	if err != nil {
-		return nil, err
-	}
 	switch algorithm {
 	case "imohash":
 		return IMOHashFile(fname)
